/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.parser.manifest;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * Encapsulates the section and header name/value information parsed from a
 * manifest.
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 */
public interface ManifestContents {

	/**
	 * @return the version number discovered in the manifest
	 */
	String getVersion();

	/**
	 * @return the main attributes discovered in the manifest
	 */
	Map<String, String> getMainAttributes();

	/**
	 * @return the section names discovered in the manifest
	 */
	List<String> getSectionNames();

	/**
	 * @param sectionName 
	 * @return the attributes discovered for a particular section in the manifest
	 */
	Map<String, String> getAttributesForSection(String sectionName);

}
