/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.parser.manifest.internal;

public final class ManifestToken implements Token {

	private static final String COLON_VALUE = ":";
	private static final String NEWLINE_VALUE = "\\n";

	private String value;
	private TokenKind kind;
	private int startoffset;
	private int endoffset;

	public static ManifestToken makeName(char[] value, int start, int end) {
		return new ManifestToken(new String(value), TokenKind.NAME, start, end);
	}

	public static ManifestToken makeValue(char[] value, int start, int end) {
		return new ManifestToken(new String(value), TokenKind.VALUE, start, end);
	}

	public static ManifestToken makeColon(int start, int end) {
		return new ManifestToken(COLON_VALUE, TokenKind.COLON, start, end);
	}

	public static Token makeNewline(int start, int end) {
		return new ManifestToken(NEWLINE_VALUE, TokenKind.NEWLINE, start, end);
	}

	private ManifestToken(String value, TokenKind kind, int start, int end) {
		this.value = value;
		this.kind = kind;
		this.startoffset = start;
		this.endoffset = end;
	}

	public String value() {
		return value;
	}

	@Override
	public String toString() {
		StringBuilder s = new StringBuilder();
		s.append("'").append(value).append("'");
		s.append("@").append(startoffset).append(":").append(endoffset);
		return s.toString();
	}

	public TokenKind getKind() {
		return kind;
	}

	public int getEndOffset() {
		return endoffset;
	}

	public int getStartOffset() {
		return startoffset;
	}

}
