/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.parser.manifest.internal;

import java.util.List;
import java.util.Map;

import com.springsource.util.parser.manifest.ManifestContents;

/**
 * <p>
 * Visited whilst processing the manifest, to build an object implementing
 * {@link ManifestContents}
 * </p>
 * 
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 */
public interface ManifestVisitor {

	public void visitManifestVersion(String version);

	/**
	 * @param isMainSection or not
	 * @param name of section
	 * @return true if parsing should continue
	 */
	public boolean visitSection(boolean isMainSection, String name);

	public void visitHeader(String name, String value);

	/**
	 * @return the version number discovered during the visit
	 */
	String getVersion();

	/**
	 * @return the main attributes discovered during the visit
	 */
	Map<String, String> getMainAttributes();

	/**
	 * @return the section names discovered during the visit
	 */
	List<String> getSectionNames();

	/**
	 * @param sectionName 
	 * @return the attributes discovered for a particular section during the visit
	 */
	Map<String, String> getAttributesForSection(String sectionName);

	/**
	 * @return the contents of the manifested as constructed during the visit
	 */
	public ManifestContents getManifestContents();

	/**
	 * Force the parsing to finish once the main section is completed (ignoring
	 * the rest of the data)
	 * 
	 * @param shouldTerminate true if parsing should finish after the main
	 *            section is visited
	 */
	public void setTerminateAfterMainSection(boolean shouldTerminate);
}
