/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.parser.manifest.internal;

/**
 * Token kinds created by the Manifest lexer.
 * <p>
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 */
public enum TokenKind {
	NAME("Name"), VALUE("Value"), COLON(":"), NEWLINE("\\n");

	private String tokenString;

	private TokenKind(String messageString) {
		this.tokenString = messageString;
	}

	public static boolean isNewline(Token t) {
		return t.getKind() == NEWLINE;
	}

	public static boolean isName(Token t) {
		return t.getKind() == NAME;
	}

	public static boolean isValue(Token t) {
		return t.getKind() == VALUE;
	}

	public static boolean isColon(Token t) {
		return t.getKind() == COLON;
	}

	public String getTokenString() {
		return tokenString;
	}
}
