/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.parser.manifest.internal;

import java.util.List;

import com.springsource.util.parser.manifest.ManifestProblem;

/**
 * Provides a stream of tokens for parsing.
 * <p>
 * <strong>Concurrent Semantics</strong><br/>
 * 
 * This class is thread safe.
 * 
 * @author Andy Clement
 */
public interface TokenStream {

	/**
	 * @return the next token and consume it
	 */
	public Token next();

	/**
	 * @return the next token but do not consume it
	 */
	public Token peek();

	/**
	 * @param offset the offset from the current TokenStream position, can be
	 *            negative.
	 * @return the token at that particular offset from the current position.
	 */
	public Token peek(int offset);

	/**
	 * @return position within the token stream
	 */
	public int getPosition();

	/**
	 * @param newPosition the new position to move to in the token stream
	 */
	public void setPosition(int newPosition);

	/**
	 * @return number of tokens in the stream
	 */
	public int getCount();

	/**
	 * @return true if problems were found whilst processing the input data
	 */
	public boolean containsProblems();

	/**
	 * @return all the problems that occurred whilst processing the input data
	 */
	public List<ManifestProblem> getProblems();

	/**
	 * @return the source context which can be used to create improved messages
	 */
	SourceContext getSourceContext();

	public String toFormattedString(boolean b);

	public String toFormattedString();

	/**
	 * @return true if there are still more tokens to process (ie. the position
	 *         is not yet at the end)
	 */
	public boolean hasMore();

	public Token peekLast();

	public void recordProblem(ManifestProblem manifestProblem);

}
